@@ -12,6 +12,7 @@ from lilya.conf import _monkay, settings as lilya_settings  # noqa
 from lilya.conf.exceptions import FieldException
 from lilya.conf.global_settings import Settings
 from lilya.datastructures import State, URLPath
+from lilya.dependencies import wrap_dependency
 from lilya.logging import LoggingConfig, setup_logging
 from lilya.middleware.asyncexit import AsyncExitStackMiddleware
 from lilya.middleware.base import DefineMiddleware
@@ -28,6 +29,7 @@ from lilya.protocols.permissions import PermissionProtocol
 from lilya.requests import Request
 from lilya.responses import Response
 from lilya.routing import BasePath, Include, Router, RoutingMethodsMixin
+from lilya.serializers import SerializerConfig, setup_serializer
 from lilya.types import (
     ApplicationType,
     ASGIApp,
@@ -865,13 +867,13 @@ class Lilya(RoutingMethodsMixin, BaseLilya):
             ),
         ] = None,
         redirect_slashes: Annotated[
-            bool,
+            bool | None,
             Doc(
                 """
                 Enable or disable automatic trailing slash redirection for HTTP routes.
                 """
             ),
-        ] = True,
+        ] = None,
         lifespan: Annotated[
             Lifespan[ApplicationType] | None,
             Doc(
@@ -884,7 +886,7 @@ class Lilya(RoutingMethodsMixin, BaseLilya):
             ),
         ] = None,
         include_in_schema: Annotated[
-            bool,
+            bool | None,
             Doc(
                 """
                 Enable or disable inclusion of the application in a OpenAPI schema integration.
@@ -894,7 +896,7 @@ class Lilya(RoutingMethodsMixin, BaseLilya):
                     flags that can be used for any possible integration.
                 """
             ),
-        ] = True,
+        ] = None,
         logging_config: Annotated[
             LoggingConfig | None,
             Doc(
@@ -903,6 +905,15 @@ class Lilya(RoutingMethodsMixin, BaseLilya):
                 """
             ),
         ] = None,
+        serializer_config: Annotated[
+            SerializerConfig | None,
+            Doc(
+                """
+                A custom SerializerConfig instance to override defaults if provided.
+                Read more about [Serializers](https://lilya.dev/serializers/).
+                """
+            ),
+        ] = None,
         populate_global_context: Annotated[
             Callable[[Connection], dict[str, Any] | Awaitable[dict[str, Any]]] | None,
             Doc(
@@ -940,7 +951,7 @@ class Lilya(RoutingMethodsMixin, BaseLilya):
                 Enable or disable OpenAPI documentation generation. Defaults to False.
                 """
             ),
-        ] = False,
+        ] = None,
         openapi_config: Annotated[
             Any | None,
             Doc(
@@ -959,7 +970,7 @@ class Lilya(RoutingMethodsMixin, BaseLilya):
                 With this flag enable, Lilya custom middleware activates those.
                 """
             ),
-        ] = False,
+        ] = None,
         root_path: Annotated[
             str | None,
             Doc(
@@ -1018,9 +1029,13 @@ class Lilya(RoutingMethodsMixin, BaseLilya):
         self.after_request_callbacks = (
             self.load_settings_value("after_request", after_request) or []
         )
-        self.dependencies = self.load_settings_value("dependencies", dependencies) or {}
+
+        # Wrap dependencies
+        _dependencies = self.load_settings_value("dependencies", dependencies) or {}
+        self.dependencies = {key: wrap_dependency(dep) for key, dep in _dependencies.items()}
 
         self.logging_config = self.load_settings_value("logging_config", logging_config)
+        self.serializer_config = self.load_settings_value("serializer_config", serializer_config)
         self.state = State()
         self.middleware_stack: ASGIApp | None = None
         self.enable_openapi = self.load_settings_value(
@@ -1031,11 +1046,17 @@ class Lilya(RoutingMethodsMixin, BaseLilya):
             "enable_intercept_global_exceptions", enable_intercept_global_exceptions
         )
         self.root_path = self.load_settings_value("root_path", root_path)
+        self.redirect_slashes = self.load_settings_value(
+            "redirect_slashes", redirect_slashes, is_boolean=True
+        )
+        self.include_in_schema = self.load_settings_value(
+            "include_in_schema", include_in_schema, is_boolean=True
+        )
 
         if self.router_class is not None:
             self.router = self.router_class(
                 routes=routes,
-                redirect_slashes=redirect_slashes,
+                redirect_slashes=self.redirect_slashes,
                 permissions=self.custom_permissions,
                 on_startup=on_startup,
                 on_shutdown=on_shutdown,
@@ -1049,6 +1070,9 @@ class Lilya(RoutingMethodsMixin, BaseLilya):
         if self.logging_config is not None:
             setup_logging(self.logging_config)
 
+        if self.serializer_config is None:
+            setup_serializer(self.serializer_config)
+
         if self.enable_openapi:
             self.configure_openapi(self.openapi_config)
 
