@@ -3,7 +3,6 @@ from __future__ import annotations
 import contextlib
 import functools
 import http.cookies
-import json
 import os
 import stat
 import time
@@ -349,16 +348,6 @@ class JSONResponse(Response):
             new_params = new_params.copy()
         else:
             new_params = {}
-        new_params.setdefault(
-            "json_encode_fn",
-            functools.partial(
-                json.dumps,
-                ensure_ascii=False,
-                allow_nan=False,
-                indent=None,
-                separators=(",", ":"),
-            ),
-        )
         new_params["post_transform_fn"] = None
         if self.encoders:
             new_params["with_encoders"] = (*self.encoders, *ENCODER_TYPES.get())
@@ -385,7 +374,7 @@ class RedirectResponse(Response):
     def __init__(
         self,
         url: str | URL,
-        status_code: int = status.HTTP_307_TEMPORARY_REDIRECT,
+        status_code: int = status.HTTP_303_SEE_OTHER,
         headers: Mapping[str, str] | None = None,
         background: Task | None = None,
         encoders: Sequence[Encoder | type[Encoder]] | None = None,
