@@ -27,6 +27,7 @@ from lilya.concurrency import run_in_threadpool
 from lilya.conf import _monkay
 from lilya.conf.global_settings import Settings
 from lilya.datastructures import URL, Header, ScopeHandler, SendReceiveSniffer, URLPath
+from lilya.dependencies import wrap_dependency
 from lilya.enums import EventType, HTTPMethod, Match, ScopeType
 from lilya.exceptions import ContinueRouting, HTTPException, ImproperlyConfigured
 from lilya.middleware.base import DefineMiddleware
@@ -318,7 +319,7 @@ class Path(BaseHandler, BasePath):
     def __init__(
         self,
         path: str,
-        handler: Callable[..., Any],
+        handler: Callable[..., Any] | str,
         *,
         methods: list[str] | None = None,
         name: str | None = None,
@@ -333,12 +334,17 @@ class Path(BaseHandler, BasePath):
     ) -> None:
         assert path.startswith("/"), "Paths must start with '/'"
         self.path = clean_path(path)
+        handler = import_string(handler) if isinstance(handler, str) else handler
         self.handler = handler
+
         self.name = get_name(handler) if name is None else name
         self.include_in_schema = include_in_schema
         self.methods: list[str] | None = methods
         self.deprecated = deprecated
-        self.dependencies = dependencies if dependencies is not None else {}
+
+        # Wrap dependencies
+        _dependencies = dependencies if dependencies is not None else {}
+        self.dependencies = {key: wrap_dependency(dep) for key, dep in _dependencies.items()}
 
         # Defition of the app
         self.__handler_app__ = handler
@@ -355,7 +361,7 @@ class Path(BaseHandler, BasePath):
         if middleware is not None:
             self.middleware = [wrap_middleware(mid) for mid in middleware]
         else:
-            self.middleware = middleware if middleware is not None else []
+            self.middleware = middleware or []
 
         self.permissions = permissions if permissions is not None else []
         self.exception_handlers = {} if exception_handlers is None else dict(exception_handlers)
@@ -422,7 +428,9 @@ class Path(BaseHandler, BasePath):
                 self.exception_handlers.update(controller.exception_handlers)
 
             if controller.dependencies:
-                self.dependencies.update(controller.dependencies)
+                self.dependencies.update(
+                    {k: wrap_dependency(v) for k, v in controller.dependencies.items()}
+                )
 
             if controller.before_request:
                 self.before_request.extend(controller.before_request)
@@ -628,7 +636,7 @@ class WebSocketPath(BaseHandler, BasePath):
     def __init__(
         self,
         path: str,
-        handler: Callable[..., Any],
+        handler: Callable[..., Any] | str,
         *,
         name: str | None = None,
         include_in_schema: bool = True,
@@ -642,12 +650,17 @@ class WebSocketPath(BaseHandler, BasePath):
         assert path.startswith("/"), "Paths must start with '/'"
         self.path = clean_path(path)
 
+        handler = import_string(handler) if isinstance(handler, str) else handler
         self.handler = handler
+
         self.name = get_name(handler) if name is None else name
         self.include_in_schema = include_in_schema
-        self.dependencies = dependencies if dependencies is not None else {}
 
-        # Defition of the app
+        # Wrap dependencies
+        _dependencies = dependencies if dependencies is not None else {}
+        self.dependencies = {key: wrap_dependency(dep) for key, dep in _dependencies.items()}
+
+        # Definition of the app
         self.__handler_app__ = handler
         while isinstance(self.__handler_app__, functools.partial):
             self.__handler_app__ = self.__handler_app__.func
@@ -905,6 +918,7 @@ class Host(BasePath):
         *,
         middleware: Sequence[DefineMiddleware] | None = None,
         permissions: Sequence[DefinePermission] | None = None,
+        dependencies: Dependencies | None = None,
         exception_handlers: Mapping[Any, ExceptionHandler] | None = None,
         before_request: Sequence[Callable[..., Any]] | None = None,
         after_request: Sequence[Callable[..., Any]] | None = None,
@@ -916,8 +930,15 @@ class Host(BasePath):
         self.host_regex, self.host_format, self.param_convertors, self.path_start = compile_path(
             host
         )
-        self.middleware = middleware if middleware is not None else []
+        if middleware is not None:
+            self.middleware = [wrap_middleware(mid) for mid in middleware]
+        else:
+            self.middleware = middleware or []
         self.permissions = permissions if permissions is not None else []
+
+        # Wrap dependencies
+        _dependencies = dependencies if dependencies is not None else {}
+        self.dependencies = {key: wrap_dependency(dep) for key, dep in _dependencies.items()}
         self.exception_handlers = {} if exception_handlers is None else dict(exception_handlers)
 
         self.wrapped_permissions = [
@@ -1195,7 +1216,10 @@ class BaseRouter:
 
         self.on_startup = [] if on_startup is None else list(on_startup)
         self.on_shutdown = [] if on_shutdown is None else list(on_shutdown)
-        self.dependencies = dependencies if dependencies is not None else {}
+
+        # Wrap dependencies
+        _dependencies = dependencies if dependencies is not None else {}
+        self.dependencies = {key: wrap_dependency(dep) for key, dep in _dependencies.items()}
 
         self.lifespan_context = handle_lifespan_events(
             on_startup=on_startup, on_shutdown=on_shutdown, lifespan=lifespan
@@ -1210,7 +1234,11 @@ class BaseRouter:
         self.include_in_schema = include_in_schema
         self.deprecated = deprecated
 
-        self.middleware = middleware if middleware is not None else []
+        if middleware is not None:
+            self.middleware = [wrap_middleware(mid) for mid in middleware]
+        else:
+            self.middleware = middleware or []
+
         self.permissions = permissions if permissions is not None else []
         self.settings_module = settings_module
         self.middleware_stack = self.app
@@ -2272,14 +2300,21 @@ class Include(BasePath):
 
         self.app = self.__base_app__
 
-        self.middleware = middleware if middleware is not None else []
+        if middleware is not None:
+            self.middleware = [wrap_middleware(mid) for mid in middleware]
+        else:
+            self.middleware = middleware or []
+
         self.permissions = permissions if permissions is not None else []
         self.exception_handlers = {} if exception_handlers is None else dict(exception_handlers)
 
         if dependencies is None and hasattr(self.__base_app__, "dependencies"):
-            self.dependencies = self.__base_app__.dependencies or {}
+            _dependencies = self.__base_app__.dependencies or {}
         else:
-            self.dependencies = dependencies or {}
+            _dependencies = dependencies or {}
+
+        # Wrap dependencies
+        self.dependencies = {key: wrap_dependency(dep) for key, dep in _dependencies.items()}
 
         self.wrapped_permissions = [
             wrap_permission(permission) for permission in permissions or []
